pub struct FilterRuleConfig {Show 15 fields
pub op: String,
pub proto: Vec<String>,
pub src_ip: Vec<String>,
pub dst_ip: Vec<String>,
pub ip: Vec<String>,
pub src_port: Vec<String>,
pub dst_port: Vec<String>,
pub port: Vec<String>,
pub flow_id: Vec<String>,
pub from: Option<String>,
pub to: Option<String>,
pub tcp_flags: Option<String>,
pub min_len: Option<u32>,
pub max_len: Option<u32>,
pub unidirectional: bool,
}Expand description
A single rule entry within [[filter.rules]] in the TOML config.
The op field controls how this rule combines with the accumulated result:
"and" (default), "or", or "not".
Fields
op: StringLogical operator: "and", "or", or "not".
proto: Vec<String>src_ip: Vec<String>dst_ip: Vec<String>ip: Vec<String>src_port: Vec<String>dst_port: Vec<String>port: Vec<String>flow_id: Vec<String>from: Option<String>to: Option<String>tcp_flags: Option<String>min_len: Option<u32>max_len: Option<u32>unidirectional: boolTrait Implementations
Sourceimpl Debug for FilterRuleConfig
impl Debug for FilterRuleConfig
Sourceimpl Default for FilterRuleConfig
impl Default for FilterRuleConfig
Sourcefn default() -> FilterRuleConfig
fn default() -> FilterRuleConfig
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for FilterRuleConfig
impl<'de> Deserialize<'de> for FilterRuleConfig
Sourcefn deserialize(value: &mut Value<'de>) -> Result<Self, DeserError>
fn deserialize(value: &mut Value<'de>) -> Result<Self, DeserError>
Given a mutable
Value, allows you to deserialize the type from it,
or accumulate 1 or more errorsAuto Trait Implementations
impl Freeze for FilterRuleConfig
impl RefUnwindSafe for FilterRuleConfig
impl Send for FilterRuleConfig
impl Sync for FilterRuleConfig
impl Unpin for FilterRuleConfig
impl UnsafeUnpin for FilterRuleConfig
impl UnwindSafe for FilterRuleConfig