Module avro

Module avro 

Apache Avro writer for packet export.

Each packet becomes one Avro record. The Avro schema is written to a companion .avsc file alongside the data file so the dataset is self-describing.

When compress_payload is true the Avro file uses the Zstd codec, which compresses all data including payload bytes.

Structs

AvroSink
Streaming Avro writer that implements PacketSink.

Constants

AVRO_SCHEMA
Avro schema definition — kept in sync with [AvroPacket].

Functions

schema_json
Return a pretty-printed version of the Avro schema (for diagnostics).