Apache Avro writer for packet export.
Each packet becomes one Avro record. The Avro schema is written to a
companion .avsc file alongside the data file so the dataset is
self-describing.
When compress_payload is true the Avro file uses the Zstd codec,
which compresses all data including payload bytes.
Structs
- Avro
Sink - Streaming Avro writer that implements
PacketSink.
Constants
- AVRO_
SCHEMA - Avro schema definition — kept in sync with [
AvroPacket].
Functions
- schema_
json - Return a pretty-printed version of the Avro schema (for diagnostics).